@@ -1,6 +1,9 @@
 import pytest
+
+import re
 from unittest import mock
 
+import sentry_sdk
 from sentry_sdk import (
     capture_exception,
     continue_trace,
@@ -11,10 +14,14 @@ from sentry_sdk import (
     is_initialized,
     start_transaction,
     set_tags,
+    configure_scope,
+    push_scope,
+    get_global_scope,
+    get_current_scope,
+    get_isolation_scope,
 )
 
 from sentry_sdk.client import Client, NonRecordingClient
-from sentry_sdk.scope import Scope
 
 
 @pytest.mark.forked
@@ -33,7 +40,7 @@ def test_get_current_span_default_hub(sentry_init):
 
     assert get_current_span() is None
 
-    scope = Scope.get_current_scope()
+    scope = get_current_scope()
     fake_span = mock.MagicMock()
     scope.span = fake_span
 
@@ -66,7 +73,7 @@ def test_traceparent_with_tracing_enabled(sentry_init):
 def test_traceparent_with_tracing_disabled(sentry_init):
     sentry_init()
 
-    propagation_context = Scope.get_isolation_scope()._propagation_context
+    propagation_context = get_isolation_scope()._propagation_context
     expected_traceparent = "%s-%s" % (
         propagation_context.trace_id,
         propagation_context.span_id,
@@ -77,7 +84,7 @@ def test_traceparent_with_tracing_disabled(sentry_init):
 @pytest.mark.forked
 def test_baggage_with_tracing_disabled(sentry_init):
     sentry_init(release="1.0.0", environment="dev")
-    propagation_context = Scope.get_isolation_scope()._propagation_context
+    propagation_context = get_isolation_scope()._propagation_context
     expected_baggage = (
         "sentry-trace_id={},sentry-environment=dev,sentry-release=1.0.0".format(
             propagation_context.trace_id
@@ -90,10 +97,10 @@ def test_baggage_with_tracing_disabled(sentry_init):
 def test_baggage_with_tracing_enabled(sentry_init):
     sentry_init(traces_sample_rate=1.0, release="1.0.0", environment="dev")
     with start_transaction() as transaction:
-        expected_baggage = "sentry-trace_id={},sentry-environment=dev,sentry-release=1.0.0,sentry-sample_rate=1.0,sentry-sampled={}".format(
+        expected_baggage_re = r"^sentry-trace_id={},sentry-sample_rand=0\.\d{{6}},sentry-environment=dev,sentry-release=1\.0\.0,sentry-sample_rate=1\.0,sentry-sampled={}$".format(
             transaction.trace_id, "true" if transaction.sampled else "false"
         )
-        assert get_baggage() == expected_baggage
+        assert re.match(expected_baggage_re, get_baggage())
 
 
 @pytest.mark.forked
@@ -106,19 +113,20 @@ def test_continue_trace(sentry_init):
     transaction = continue_trace(
         {
             "sentry-trace": "{}-{}-{}".format(trace_id, parent_span_id, parent_sampled),
-            "baggage": "sentry-trace_id=566e3688a61d4bc888951642d6f14a19",
+            "baggage": "sentry-trace_id=566e3688a61d4bc888951642d6f14a19,sentry-sample_rand=0.123456",
         },
         name="some name",
     )
     with start_transaction(transaction):
         assert transaction.name == "some name"
 
-        propagation_context = Scope.get_isolation_scope()._propagation_context
+        propagation_context = get_isolation_scope()._propagation_context
         assert propagation_context.trace_id == transaction.trace_id == trace_id
         assert propagation_context.parent_span_id == parent_span_id
         assert propagation_context.parent_sampled == parent_sampled
         assert propagation_context.dynamic_sampling_context == {
-            "trace_id": "566e3688a61d4bc888951642d6f14a19"
+            "trace_id": "566e3688a61d4bc888951642d6f14a19",
+            "sample_rand": "0.123456",
         }
 
 
@@ -126,7 +134,7 @@ def test_continue_trace(sentry_init):
 def test_is_initialized():
     assert not is_initialized()
 
-    scope = Scope.get_global_scope()
+    scope = get_global_scope()
     scope.set_client(Client())
     assert is_initialized()
 
@@ -179,3 +187,31 @@ def test_set_tags(sentry_init, capture_events):
         "tag2": "updated",
         "tag3": "new",
     }, "Updating tags with empty dict changed tags"
+
+
+def test_configure_scope_deprecation():
+    with pytest.warns(DeprecationWarning):
+        with configure_scope():
+            ...
+
+
+def test_push_scope_deprecation():
+    with pytest.warns(DeprecationWarning):
+        with push_scope():
+            ...
+
+
+def test_init_context_manager_deprecation():
+    with pytest.warns(DeprecationWarning):
+        with sentry_sdk.init():
+            ...
+
+
+def test_init_enter_deprecation():
+    with pytest.warns(DeprecationWarning):
+        sentry_sdk.init().__enter__()
+
+
+def test_init_exit_deprecation():
+    with pytest.warns(DeprecationWarning):
+        sentry_sdk.init().__exit__(None, None, None)
