@@ -6,8 +6,8 @@ from unittest import mock
 import pytest
 
 import sentry_sdk
-from sentry_sdk import Scope, metrics
-from sentry_sdk.tracing import TRANSACTION_SOURCE_ROUTE
+from sentry_sdk import metrics
+from sentry_sdk.tracing import TransactionSource
 from sentry_sdk.envelope import parse_json
 
 try:
@@ -538,8 +538,9 @@ def test_transaction_name(
     ts = time.time()
     envelopes = capture_envelopes()
 
-    scope = Scope.get_current_scope()
-    scope.set_transaction_name("/user/{user_id}", source="route")
+    sentry_sdk.get_current_scope().set_transaction_name(
+        "/user/{user_id}", source=TransactionSource.ROUTE
+    )
     metrics.distribution("dist", 1.0, tags={"a": "b"}, timestamp=ts)
     metrics.distribution("dist", 2.0, tags={"a": "b"}, timestamp=ts)
     metrics.distribution("dist", 2.0, tags={"a": "b"}, timestamp=ts)
@@ -580,7 +581,7 @@ def test_metric_summaries(
     envelopes = capture_envelopes()
 
     with sentry_sdk.start_transaction(
-        op="stuff", name="/foo", source=TRANSACTION_SOURCE_ROUTE
+        op="stuff", name="/foo", source=TransactionSource.ROUTE
     ) as transaction:
         metrics.increment("root-counter", timestamp=ts)
         with metrics.timing("my-timer-metric", tags={"a": "b"}, timestamp=ts):
